@@ -65,6 +65,14 @@ module Generic = struct
 	()
       end
 
+    let test_intersect g =
+      let gg = O.intersect g g in
+      assert (G.nb_vertex gg = G.nb_vertex g);
+      assert (G.nb_edges gg = G.nb_edges g);
+      let g0 = O.intersect g (G.create ()) in
+      assert (G.is_empty g0);
+      ()
+
     let g = G.create ()
     let () =
       let v1 = G.V.create 1 in
@@ -77,6 +85,7 @@ module Generic = struct
       G.add_edge g v2 v2;
       G.add_edge g v2 v2;
       test_mirror g;
+      test_intersect g;
       assert (G.nb_vertex g = V.v && G.nb_edges g = V.e);
       G.remove_vertex g v1;
       assert (G.nb_vertex g = 2 && G.nb_edges g = 1);
@@ -140,7 +149,17 @@ module Generic = struct
     module O = Oper.P(G)
     let test_mirror g =
       let g' = O.mirror g in
-      assert (G.nb_vertex g = G.nb_vertex g')
+      assert (G.nb_vertex g = G.nb_vertex g');
+      G.iter_edges (fun v1 v2 -> assert (G.mem_edge g' v2 v1)) g;
+      G.iter_edges (fun v1 v2 -> assert (G.mem_edge g v2 v1)) g'
+
+    let test_intersect g =
+      let gg = O.intersect g g in
+      assert (G.nb_vertex gg = G.nb_vertex g);
+      assert (G.nb_edges gg = G.nb_edges g);
+      let g0 = O.intersect g G.empty in
+      assert (G.is_empty g0);
+      ()
 
     let () =
       let g = G.empty in
@@ -154,6 +173,7 @@ module Generic = struct
       let g = G.add_edge g v2 v2 in
       let g = G.add_edge g v2 v2 in
       test_mirror g;
+      test_intersect g;
       assert (G.nb_vertex g = V.v && G.nb_edges g = V.e);
       let g = G.remove_vertex g v1 in
       assert (G.nb_vertex g = 2 && G.nb_edges g = 1);
@@ -736,17 +756,22 @@ module Test_reduction = struct
 
   let check_included g1 g2 =
     iter_vertex (fun v -> assert (mem_vertex g2 v)) g1;
-    iter_edges (fun u v -> assert (mem_edge g1 u v)) g1
+    iter_edges (fun u v -> assert (mem_edge g2 u v)) g1
 
   let check_same_graph g1 g2 =
     check_included g1 g2;
     check_included g2 g1
 
   let test v e =
+    (* Format.eprintf "v=%d e=%d@." v e; *)
     let g = R.graph ~loops:true ~v ~e () in
+    (* Format.eprintf "g:@."; *)
+    (* iter_edges (fun u v -> Format.eprintf "  %d->%d@." u v) g; *)
     let t = O.transitive_closure g in
     check_included g t;
     let r = O.transitive_reduction g in
+    (* Format.eprintf "r:@."; *)
+    (* iter_edges (fun u v -> Format.eprintf "  %d->%d@." u v) r; *)
     check_included r g;
     check_same_graph (O.transitive_closure r) t
 
@@ -765,16 +790,20 @@ module Test_reduction = struct
     add_edge g 2 5;
     let r = O.transitive_reduction g in
     check_included r g;
+    (* iter_edges (fun u v -> Format.eprintf "  %d->%d@." u v) r; *)
     assert (nb_edges r = 4);
     assert (not (mem_edge r 2 5));
     ()
 
+  (* issue #145 *)
+  let () =
+    let g = create () in
+    for v = 1 to 3 do add_vertex g v done;
+    add_edge g 1 2; add_edge g 2 1;
+    add_edge g 3 1; add_edge g 3 2;
+    let r = O.transitive_reduction g in
+    check_same_graph (O.transitive_closure r) (O.transitive_closure g)
+
 end
 
 let () = Format.printf "check: all tests succeeded@."
-
-(*
-Local Variables:
-compile-command: "make -C .. check"
-End:
-*)
